coherence.upnp.services.clients.av_transport_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.clients.av_transport_client (module)

class `AVTransportClient`(service)

  Bases: `coherence.log.LogAble`

  `logCategory` = 'avtransportclient'
  `remove`()
  `subscribe_for_variable`(var_name, callback, signal=False)
  `set_av_transport_uri`(instance_id=0, current_uri='', current_uri_metadata='')
  `set_next_av_transport_uri`(instance_id=0, next_uri='', next_uri_metadata='')
  `get_media_info`(instance_id=0)
  `get_media_info_ext`(instance_id=0)
  `get_transport_info`(instance_id=0)
  `get_position_info`(instance_id=0)
  `get_device_capabilities`(instance_id=0)
  `get_transport_settings`(instance_id=0)
  `pause`(instance_id=0)
  `play`(instance_id=0, speed=1)
  `stop`(instance_id=0)
  `record`(instance_id=0)
  `seek`(instance_id=0, unit='', target=0)
  `next`(instance_id=0)
  `previous`(instance_id=0)
  `get_current_transport_actions`(instance_id=0)